@@ -2,18 +2,25 @@ import sys
 import json
 from ..task_image import TaskImage
 from ..const import CONTEXT_FILE_NAME
+from ..config import Config
+from ..context import Context
 from .build import build
 
 
-def push() -> TaskImage:
-    image = build()
+def push(config: Config, **kwargs) -> TaskImage:
+    context = Context.open(config)
+    image = TaskImage.open(context)
 
-    if image is None or '/' not in image.name:
+    if image is None:
+        print(f'Error: Failed to resolve task image')
+        return
+
+    if '/' not in image.name:
         print(f'Error: You must specify a full image name in '
               f'{CONTEXT_FILE_NAME} before you can push')
         return
 
-    sys.stdout.write('pushing...')
+    sys.stdout.write('Pushing...')
     logs = image.push()
     progress = {}
     for log in logs:
@@ -25,6 +32,9 @@ def push() -> TaskImage:
             if 'id' in update and 'progressDetail' in update:
                 id = update['id']
                 progress[id] = update['progressDetail']
+            if 'errorDetail' in update:
+                print('\rError:', update['error'])
+                return
 
         current = 0
         total = 0
@@ -34,9 +44,9 @@ def push() -> TaskImage:
 
         if total > 0:
             pct = 100 * min(current / total, 1.0)
-            sys.stdout.write(f'\rpushing... {pct:0.2f}%  ')
+            sys.stdout.write(f'\rPushing... {pct:0.2f}%  ')
             sys.stdout.flush()
 
-    sys.stdout.write(f'\rpushing... done       \n')
+    sys.stdout.write('\rpushing... done       \n')
     sys.stdout.flush()
     return image
