@@ -2,12 +2,13 @@ from __future__ import annotations
 import asyncio
 from concurrent.futures import Future
 from cowait.types import type_from_description
-from .errors import TaskError
+from .errors import TaskError, StoppedError
+from .instance import TaskInstance
 from .definition import TaskDefinition
-from .status import WAIT, WORK, FAIL, DONE
+from .status import WAIT, WORK, FAIL, DONE, STOP
 
 
-class RemoteTask(TaskDefinition):
+class RemoteTask(TaskInstance):
     def __init__(self, taskdef: TaskDefinition, cluster):
         kwargs = taskdef.serialize()
         super().__init__(**kwargs)
@@ -16,9 +17,6 @@ class RemoteTask(TaskDefinition):
         self.cluster = cluster
         self.future = Future()
         self.awaitable = asyncio.wrap_future(self.future)
-        self.status = WAIT
-        self.error = None
-        self.result = None
 
     def __await__(self):
         return self.awaitable.__await__()
@@ -36,7 +34,10 @@ class RemoteTask(TaskDefinition):
             raise RuntimeError('Cant complete a failed task')
 
         if self.status == DONE and status == FAIL:
-            raise RuntimeError('Cant fail a failed completed')
+            raise RuntimeError('Cant fail a completed task')
+
+        if status == STOP and not self.future.done():
+            self.future.set_exception(StoppedError(f'Remote task {self.id} was stopped'))
 
         # update status
         self.status = status
@@ -76,7 +77,7 @@ class RemoteTask(TaskDefinition):
             await asyncio.sleep(interval)
             slept += interval
 
-    async def call(self, method, args={}):
+    async def call(self, method, args={}) -> any:
         if self.status == WAIT:
             await self.wait_for_init()
         elif self.status != WORK:
@@ -86,13 +87,23 @@ class RemoteTask(TaskDefinition):
 
         return await self.conn.rpc.call(method, args)
 
-    async def stop(self):
-        # special case RPC - it always causes a send exception
+    async def stop(self) -> None:
+        if self.status == STOP:
+            return
         await self.call('stop')
 
+    def logs(self):
+        return self.cluster.logs(self)
+
     def __getattr__(self, method):
         async def magic_rpc(*args, **kwargs):
             if len(args) > 0:
                 raise TypeError('Positional arguments are not supported for RPC methods')
             return await self.call(method, kwargs)
         return magic_rpc
+
+    def __str__(self):
+        return f'RemoteTask({self.id}, {self.status}, {self.inputs})'
+
+    def __repr__(self):
+        return self.__str__()
